Class: Mobility::Backends::Sequel::Hstore
- Defined in:
- lib/mobility/backends/sequel/hstore.rb
Overview
Implements the Hstore backend for Sequel models.
Defined Under Namespace
Classes: QueryMethods
Backend Accessors collapse
-
#read(locale, **options) ⇒ Object
Gets the translated value for provided locale from configured backend.
-
#write(locale, value, options = {}) ⇒ Object
Updates translation for provided locale without calling backend's methods to persist the changes.
Methods inherited from PgHash
Methods included from HashValued
Methods included from Mobility::Backends::Sequel
included, #setup_query_methods
Instance Method Details
#read(locale, **options) ⇒ Object
Gets the translated value for provided locale from configured backend.
|
|
# File 'lib/mobility/backends/sequel/hstore.rb', line 15
|
#write(locale, value, options = {}) ⇒ Object
Updates translation for provided locale without calling backend's methods to persist the changes.
21 22 23 |
# File 'lib/mobility/backends/sequel/hstore.rb', line 21 def write(locale, value, = {}) super(locale, value && value.to_s, ) end |