Module: Mobility::Plugins::ActiveModel
- Defined in:
- lib/mobility/plugins/active_model/dirty.rb,
lib/mobility/plugins/active_model.rb
Overview
Dirty tracking for models which include the ActiveModel::Dirty module.
Assuming we have an attribute title, this module will add support for the
following methods:
title_changed?title_changetitle_wastitle_will_change!title_previously_changed?title_previous_changerestore_title!
In addition, the private method restore_attribute! will also restore the
value of the translated attribute if passed to it.
Defined Under Namespace
Modules: Dirty